@@ -94,15 +94,8 @@ class API(object):
             background = not app.debug
 
             for resource in self.resources:
-                if not hasattr(resource, 'indexes'):
-                    continue
-
-                for index in resource.indexes:
-                    resource.collection().ensure_index(
-                        index['key'],
-                        unique=index.get('unique'),
-                        background=background
-                    )
+                if hasattr(resource, 'ensure_indexes'):
+                    resource.ensure_indexes(background=background)
 
     @property
     def db(self):
