@@ -1,13 +1,6 @@
 import time
 import threading
 
-from wsgiref.simple_server import make_server, WSGIRequestHandler
-
-
-class QuietHandler(WSGIRequestHandler):
-    def log_request(*args, **kwargs):
-        pass
-
 
 class LiveServer(object):
     """
@@ -30,10 +23,8 @@ class LiveServer(object):
 
         Source: https://github.com/jerrykan/wsgi-liveserver/blob/master/wsgi_liveserver.py
         """
-
-        server = make_server(
-            host, port, self.app, handler_class=QuietHandler
-        )
+        def start(app, port, host):
+            app.run(host=host, port=port, threaded=True, debug=False)
 
         # Create URL
         server_name = '{0}:{1}'.format(host, port)
@@ -45,23 +36,17 @@ class LiveServer(object):
         })
 
         # Start the test server in the background
-        thread = threading.Thread(target=server.serve_forever)
+        thread = threading.Thread(target=start, args=[self.app, port, host])
         thread.start()
 
-        # Give the test server a bit of time to prepare for handling requests
-        time.sleep(.1)
-
-        self.server = server
         self.thread = thread
         self.url = url
         self.port = port
         self.server_name = server_name
 
+        time.sleep(1)
+
     def stop(self):
         """ Stop live server, joining thread until terminated. """
-        self.server.shutdown()
-
-        # Join the thread until shutdown
+        self.thread._Thread__stop()
         self.thread.join()
-
-        assert not self.thread.is_alive()
