@@ -8,7 +8,7 @@ app = Flask('test')
 app.debug = True
 
 db = PyMongo(app)
-api = API('flask_json_resource.features.steps')
+api = API('flask_json_resource.features')
 
 
 @api.register()
