@@ -18,6 +18,38 @@ def context():
     return context
 
 
+@when(re.compile('I have a (?P<resource>\w+) resource: (?P<data>.+)'))
+def insert_resource(app, context, resource, data):
+    data = json.loads(data)
+
+    with app.test_request_context():
+        resource = getattr(context.resources, resource)(data)
+
+        resource.save()
+
+
+@given(re.compile('a (?P<resource>\w+) resource: (?P<data>.+)'))
+def given_resource(app, context, resource, data):
+    insert_resource(app, context, resource, data)
+
+
+@given(re.compile('also a (?P<resource>\w+) resource: (?P<data>.+)'))
+def also_give(app, context, resource, data):
+    insert_resource(app, context, resource, data)
+
+
+@when(re.compile('I create a (?P<resource>\w+) resource: (?P<data>.+)'))
+def create_resource(app, context, resource, data):
+    data = json.loads(data)
+
+    with app.test_request_context():
+        resource = getattr(context.resources, resource)(data)
+        resource.save(create=True)
+
+        context.resource = resource
+
+
+
 @given(re.compile('I use "(?P<value>.+)" as the "(?P<header>.+)" header'))
 def given_header(context, header, value):
     context.session.headers.update({header: value})
